@@ -20,7 +20,7 @@
 #  respective owners and no grant or license is provided thereof.
 
 package PDL::Opt::Simplex::Simple;
-$VERSION = '1.1';
+$VERSION = '1.2';
 
 use strict;
 use warnings;
@@ -62,6 +62,8 @@ sub new
 		$self->{srand} = srand();
 	}
 
+	$self->{srand} //= 'random seed is unknown, see this issue: https://github.com/PDLPorters/pdl/issues/398';
+
 	# _ssize is the array for multiple simplex retries.
 	if (ref($self->{ssize}) eq 'ARRAY')
 	{
@@ -1478,6 +1480,45 @@ ideal values for its control.
 If you are interested, here is a video about the antenna construction: 
 L<https://youtu.be/Ab_oJHlENwo>
 
+=head2 PDL variable considerations
+
+You can use pdl's as vars in your code, but at the moment those pdl's must be singletons.
+
+This will work:
+
+	->new({
+		vars => { x => pdl(5) }
+	}, ...)
+
+but this will not:
+
+	->new({
+		vars => { x => pdl([1,2,3]) }
+	}, ...)
+
+If you need PDL vectors in your C<f()> call then this could work because
+L<PDL::Opt::Simplex::Simple> can optimize perl ARRAY ref's:
+
+	->new({
+		vars => { x => [1,2,3] }
+	}, 
+	f => sub {
+		my $vars = shift;
+		my $x = pdl $vars->{x};
+
+		# do stuff here, maybe return the sum:
+
+		return unpdl(sum $x);
+	},
+	...)
+
+Future support for this is possible, but there is one major consideration: PDLs
+need to be generically decomposed into a 1-dimensionaly PDL before passing it
+to simplex() and then convert it back to the original N-dimensional form before
+passing it to the user's C<f()> call.  This would then enable hash-named
+N-dimensional pdl optimization.
+
+Patches welcome ;)
 
 =head1 SEE ALSO
 
